@@ -12,20 +12,18 @@
 
 #include "errors.hpp"
 
-#include "ndebug.hpp"
-
 namespace acommon {
 
   // PosibErr<type> is a special Error handling device that will make
   // sure that an error is properly handled.  It is expected to be
-  // used as the return type of the function It will automatically
+  // used as the return type of the function It will automatitcly
   // convert to the "normal" return type however if the normal
   // returned type is accessed and there is an "unhandled" error
   // condition it will abort It will also abort if the object is
   // destroyed with an "unhandled" error condition.  This includes
-  // ignoring the return type of a function returning an error
+  // ignoring the return type of a function returing an error
   // condition.  An error condition is handled by simply checking for
-  // the presence of an error, calling ignore, or taking ownership of
+  // the precence of an error, calling ignore, or taking owenership of
   // the error.
 
   enum WhichErr { PrimErr, SecErr };
@@ -49,34 +47,6 @@ namespace acommon {
                                 refcount(1) {}
     };
     ErrPtr * err_;
-
-  protected:
-
-    void posib_handle_err() const {
-#ifndef NDEBUG
-      if (err_ && !err_->handled)
-	handle_err();
-#endif
-    }
-
-    void copy(const PosibErrBase & other) {
-      err_ = other.err_;
-      if (err_) {
-	++ err_->refcount;
-      }
-    }
-    void destroy() {
-      if (err_ == 0) return;
-      -- err_->refcount;
-      if (err_->refcount == 0) {
-#ifndef NDEBUG
-	if (!err_->handled)
-	  handle_err();
-#endif
-	del();
-      }
-    }
-
   public:
     PosibErrBase() 
       : err_(0) {}
@@ -145,13 +115,40 @@ namespace acommon {
       return set(inf, p1, p2, p3, p4);
     }
 
-    // These should only be called _after_ set is called
+    // This should only be called _after_ set is called
     PosibErrBase & with_file(ParmString fn, int lineno = 0);
-    PosibErrBase & with_key(ParmString prefix, ParmString key);
     
     PosibErrBase & set(const ErrorInfo *, 
 		       ParmString, ParmString, ParmString, ParmString);
 
+
+  protected:
+
+    void posib_handle_err() const {
+#ifndef NDEBUG
+      if (err_ && !err_->handled)
+	handle_err();
+#endif
+    }
+
+    void copy(const PosibErrBase & other) {
+      err_ = other.err_;
+      if (err_) {
+	++ err_->refcount;
+      }
+    }
+    void destroy() {
+      if (err_ == 0) return;
+      -- err_->refcount;
+      if (err_->refcount == 0) {
+#ifndef NDEBUG
+	if (!err_->handled)
+	  handle_err();
+#endif
+	del();
+      }
+    }
+
   private:
 
 #ifndef NDEBUG
@@ -161,31 +158,21 @@ namespace acommon {
     void del();
   };
 
-  template <>
-  class PosibErr<void> : public PosibErrBase
-  {
-  public:
-    PosibErr(const PosibErrBase & other) 
-      : PosibErrBase(other) {}
-
-    PosibErr() {}
-  };
-
   template <typename Ret>
   class PosibErr : public PosibErrBase
   {
   public:
-    PosibErr() : data() {}
+    PosibErr() {}
 
     PosibErr(const PosibErrBase & other) 
-      : PosibErrBase(other), data() {}
+      : PosibErrBase(other) {}
 
     template <typename T>
     PosibErr(const PosibErr<T> & other)
       : PosibErrBase(other), data(other.data) {}
 
     PosibErr(const PosibErr<void> & other)
-      : PosibErrBase(other), data() {}
+      : PosibErrBase(other) {}
 
     PosibErr& operator= (const PosibErr & other) {
       data = other.data;
@@ -199,6 +186,16 @@ namespace acommon {
     Ret data;
   };
 
+  template <>
+  class PosibErr<void> : public PosibErrBase
+  {
+  public:
+    PosibErr(const PosibErrBase & other) 
+      : PosibErrBase(other) {}
+
+    PosibErr() {}
+  };
+
 //
 //
 //
@@ -216,6 +213,7 @@ namespace acommon {
 				      ParmString p1 = 0, ParmString p2 = 0,
 				      ParmString p3 = 0, ParmString p4 = 0)
   {
+    if (inf == cant_extend_options) abort();
     return PosibErrBase().prim_err(inf, p1, p2, p3, p4);
   }
 
@@ -224,23 +222,25 @@ namespace acommon {
   //
   //
   //
+#ifndef __SUNPRO_CC
+  inline String::String(const PosibErr<String> & other)
+  {
+    assign_only(other.data.data(), other.data.size());
+  }
+#endif
   inline String & String::operator= (const PosibErr<const char *> & s)
   {
     *this = s.data;
     return *this;
   }
-
-  inline bool operator== (const PosibErr<String> & x, const char * y)
-  {
-    return x.data == y;
-  }
-  inline bool operator!= (const PosibErr<String> & x, const char * y)
-  {
-    return x.data != y;
-  }
+  //inline String & String::operator= (const PosibErr<String> & s)
+  //{
+  //  std::string::operator=(s.data);
+  //  return *this;
+  //}
 
   inline ParmString::ParmString(const PosibErr<const char *> & s)
-    : str_(s.data), size_(UINT_MAX) {}
+    : str_(s.data) {}
 
   inline ParmString::ParmString(const PosibErr<String> & s)
     : str_(s.data.c_str()), size_(s.data.size()) {}
