@@ -15,19 +15,17 @@
 #include "errors.hpp"
 #include "convert.hpp"
 
-//#define FILTER_PROGRESS_CONTROL "tex-filter-debug.log"
-//#include "filter_debug.hpp"
-//#include <stdio.h>
-//#include <cstdio>
+#define FILTER_PROGRESS_CONTROL "tex-filter-debug.log"
+#include "loadable-filter-API.hpp"
+#include <stdio.h>
+#include <cstdio>
 #include "filter_char_vector.hpp"
 #include "string_list.hpp"
 #include "string_enumeration.hpp"
 
-#include "gettext.h"
 
-namespace {
+namespace acommon {
 
-  using namespace acommon;
 
   class TexFilter : public IndividualFilter 
   {
@@ -47,8 +45,8 @@ namespace {
 
     class Commands : public StringMap {
     public:
-      PosibErr<bool> add(ParmStr to_add);
-      PosibErr<bool> remove(ParmStr to_rem);
+      PosibErr<bool> add(ParmString to_add);
+      PosibErr<bool> remove(ParmString to_rem);
     };
     
     Commands commands;
@@ -92,9 +90,9 @@ namespace {
     //fprintf(stderr,"name %s \n",name_);
 
     commands.clear();
-    opts->retrieve_list("f-tex-command", &commands);
+    opts->retrieve_list("filter-tex-command", &commands);
     
-    check_comments = opts->retrieve_bool("f-tex-check-comments");
+    check_comments = opts->retrieve_bool("filter-tex-check-comments");
 
     reset();
     return true;
@@ -243,19 +241,17 @@ namespace {
   // TexFilter::Commands
   //
 
-  PosibErr<bool> TexFilter::Commands::add(ParmStr value) {
+  PosibErr<bool> TexFilter::Commands::add(ParmString value) {
     int p1 = 0;
     while (!asc_isspace(value[p1])) {
       if (value[p1] == '\0') 
-	return make_err(bad_value, value,"",
-                        _("a string of 'o','O','p',or 'P'"));
+	return make_err(bad_value, value,"","a string of o,O,p, or P");
       ++p1;
     }
     int p2 = p1 + 1;
     while (asc_isspace(value[p2])) {
       if (value[p2] == '\0') 
-	return make_err(bad_value, value,"",
-                        _("a string of 'o','O','p',or 'P'"));
+	return make_err(bad_value, value,"","a string of o,O,p, or P");
       ++p2;
     }
     String t1; t1.assign(value,p1);
@@ -263,13 +259,13 @@ namespace {
     return StringMap::replace(t1, t2);
   }
   
-  PosibErr<bool> TexFilter::Commands::remove(ParmStr value) {
+  PosibErr<bool> TexFilter::Commands::remove(ParmString value) {
     int p1 = 0;
     while (!asc_isspace(value[p1]) && value[p1] != '\0') ++p1;
     String temp; temp.assign(value,p1);
     return StringMap::remove(temp);
   }
-#if 0  
+  
   //
   //
   class Recode {
@@ -356,7 +352,7 @@ namespace {
       keylen=strlen(code[0]);
     }
     while (begin && end && *begin) {
-      while (end && *end && (*end != ',')) {
+      while (end && *end && (*end != ':')) {
         end++;
       }
       if (end  && (begin != end)) {
@@ -482,11 +478,11 @@ namespace {
 
   PosibErr<bool> TexEncoder::setup(Config * config) {
     name_ = "tex-encoder";
-    order_num_ = 0.40;
+    order_num_ = 0.4;
 
     StringList multibytechars;
 
-    config->retrieve_list("f-tex-multi-byte", &multibytechars);
+    config->retrieve_list("filter-tex-multi-byte", &multibytechars);
 
     Conv conv; // this a quick and dirty fix witch will only work for
                // iso-8859-1.  Full unicode support needs to be
@@ -588,7 +584,7 @@ namespace {
 
     StringList multibytechars;
     
-    config->retrieve_list("f-tex-multi-byte", &multibytechars);
+    config->retrieve_list("filter-tex-multi-byte", &multibytechars);
 
     Conv conv; // this a quick and dirty fix witch will only work for
                // iso-8859-1.  Full unicode support needs to be
@@ -610,9 +606,6 @@ namespace {
                 name_,multibyte);
         continue;
       }
-      FDEBUGPRINTF("next multibyte chars `");
-      FDEBUGPRINTF(multibyte);
-      FDEBUGPRINTF("'\n");
 
       int countmulti=0;
 
@@ -620,9 +613,6 @@ namespace {
              !multibytes[countmulti].setExpansion(multibyte)) {
         countmulti++;
       }
-      FDEBUGPRINTF("next multibyte chars `");
-      FDEBUGPRINTF(multibyte);
-      FDEBUGPRINTF("'\n");
       if (countmulti >= multibytes.size()) {
         multibytes.resize(multibytes.size()+1);
         if (!multibytes[multibytes.size()-1].setExpansion(multibyte)) {
@@ -630,13 +620,10 @@ namespace {
           continue;
         }
       }
-      FDEBUGPRINTF("next multibyte chars `");
-      FDEBUGPRINTF(multibyte);
-      FDEBUGPRINTF("'\n");
     }
     StringList hyphenChars;
     
-    config->retrieve_list("f-tex-hyphen", &hyphenChars);
+    config->retrieve_list("filter-tex-hyphen", &hyphenChars);
 
     StringEnumeration * hyphenList=hyphenChars.elements();
     const char * hyphen=NULL;
@@ -749,15 +736,8 @@ namespace {
   TexDecoder::~TexDecoder(){
     FDEBUGCLOSE;
   }
-#endif
+    
+  ACTIVATE_ENCODER(acommon,TexEncoder,tex);
+  ACTIVATE_FILTER(acommon,TexFilter,tex);
+  ACTIVATE_DECODER(acommon,TexDecoder,tex);
 }
-
-C_EXPORT 
-IndividualFilter * new_aspell_tex_filter() {return new TexFilter;}
-
-#if 0
-C_EXPORT 
-IndividualFilter * new_aspell_tex_decoder() {return new TexDecoder;}
-C_EXPORT 
-IndividualFilter * new_aspell_tex_encoder() {return new TexEncoder;}
-#endif
